# Generated by Django 2.2 on 2023-02-10 14:30

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django', '0008_auto_20230210_1029'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='documentitem',
            name='document',
        ),
        migrations.AlterField(
            model_name='templateitem',
            name='template',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='items', to='django.Template'),
        ),
        migrations.DeleteModel(
            name='Document',
        ),
        migrations.DeleteModel(
            name='DocumentItem',
        ),
    ]
