<div class="form-group">
    <div class="col-sm-4">
        <label>
            {{field.label}}
        </label>
    </div>
    <div class="col-sm-8">
        <div class="input-group">
            <span class="input-group-btn">
                <button id="upload_button_browse" type="button" class="btn btn-default">
                    <span class="glyphicon glyphicon-envelope"></span>
                </button>
            </span>
            <input id="{{field.full_name}}"
               name="{{field.full_name}}"
               class="form-control"
               type="text"
               value="{{field.value_as_str}}"
               {% if tabindex %} tabindex="{{tabindex}}"{% endif %}
               {% if field.disabled %}disabled{% endif %}
               {% if field.autocomplete %}autocomplete="{{field.autocomplete}}"{% endif %} style="margin-top: 1px"/>
        </div>
        {% for error in field.errors %}
        <div class="red">{{ error }}</div>
        {% endfor %}
    </div>
</div>
